@@ -2,6 +2,4 @@ from . import models
 from . import losses
 from . import layers
 from . import activations
-# import losses
-# import layers
-# import activations
\ No newline at end of file
+from . import optimizers
\ No newline at end of file
